@@ -283,8 +283,8 @@ static void SetPktHdr(DAQ_PktHdr_t* phdr, ssize_t len)
 
 //-------------------------------------------------------------------------
 
-// forward all but drops and blacklists:
-static const int s_fwd[MAX_DAQ_VERDICT] = { 1, 0, 1, 1, 0, 1 };
+// forward all but drops, retries and blacklists:
+static const int s_fwd[MAX_DAQ_VERDICT] = { 1, 0, 1, 1, 0, 1, 0 };
 
 static int ipfw_daq_acquire (
     void* handle, int cnt, DAQ_Analysis_Func_t callback, DAQ_Meta_Func_t metaback, void* user)
